==> apeman-task-contrib-mkdir-1.0.11.tgz: package/README.md <==
apeman-task-contrib-mkdir
======

[![Build Status][my_travis_badge_url]][my_travis_url]
[![Code Climate][my_codeclimate_badge_url]][my_codeclimate_url]
[![Code Coverage][my_coveralls_badge_url]][my_coveralls_url]
[![npm version][my_npm_budge_url]][my_npm_url]

Apeman task contribution plugin to make directories.


Installation
-------

Install module via [npm][npm_url]

```bash
$ npm install apeman-task-contrib-mkdir --save-dev
```

Usage
-------

1. Define a task at `$tasks` property in you Apemanfile.
2. Set "apeman-task-contrib-mkdir" to `$worker` property.

```javascript
/**
 * This is example Apemanfile to use "apeman-task-contrib-mkdir".
 */

"use strict";

module.exports = {
    $pkg: {/*...*/},
    $tasks: {
        "structure-my-project": {
            "$worker": "apeman-task-contrib-mkdir",
            // Directory names to generate.
            "$args": [
                "bin",
                "lib",
                "docs",
                "docs/apiguide",
                "test",
                "test/unit_tests"
            ],
            "$options": {}
        }
    }
};
```

Then, run the task via [apeman task command][apeman_task_doc_url].

```bash
// This will run the defined task.
$ apeman task structure-my-project
```

Options
-------

Values which can be passed to `$options` property.

| Name | Description |
| ---- | ----------- |


License
-------

This software is released under the [MIT License][my_license_url].


Links
-------

+ [apeman][apeman_url]


[npm_url]: https://www.npmjs.com/
[apeman_url]: https://github.com/apeman-repo/apeman
[apeman_task_doc_url]: https://github.com/apeman-repo/apeman#task
[my_repo_url]: https://github.com/apeman-repo/apeman-task-contrib-mkdir
[my_travis_url]: http://travis-ci.org/apeman-repo/apeman-task-contrib-mkdir
[my_travis_badge_url]: http://img.shields.io/travis/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_license_url]: https://github.com/apeman-repo/apeman-task-contrib-mkdir/blob/master/LICENSE
[my_codeclimate_url]: http://codeclimate.com/github/apeman-repo/apeman-task-contrib-mkdir
[my_codeclimate_badge_url]: http://img.shields.io/codeclimate/github/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_coveralls_url]: https://coveralls.io/github/apeman-repo/apeman-task-contrib-mkdir
[my_coveralls_badge_url]: http://img.shields.io/coveralls/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_npm_url]: http://www.npmjs.org/package/apeman-task-contrib-mkdir
[my_npm_budge_url]: http://img.shields.io/npm/v/apeman-task-contrib-mkdir.svg?style=flat
[coz_url]: http://okunishinishi.github.io/node-coz/apiguide

==> apeman-task-contrib-mkdir-1.2.1.tgz: package/README.md <==
apeman-task-contrib-mkdir
======

[![Build Status][my_travis_badge_url]][my_travis_url]
[![Code Climate][my_codeclimate_badge_url]][my_codeclimate_url]
[![Code Coverage][my_codeclimate_coverage_badge_url]][my_codeclimate_url]
[![npm version][my_npm_budge_url]][my_npm_url]

Apeman task contribution plugin to make directories.


Installation
-------

Install module via [npm][npm_url]

```bash
$ npm install apeman-task-contrib-mkdir --save-dev
```

Usage
-------

1. Define a task at `$tasks` property in you Apemanfile.
2. Set "apeman-task-contrib-mkdir" to `$invoke` property.

```javascript
/**
 * This is example Apemanfile to use "apeman-task-contrib-mkdir".
 */

"use strict";

module.exports = {
    $pkg: {/*...*/},
    $tasks: {
        // Define your own task.
        "my-task-01": {
            "$invoke": "apeman-task-contrib-mkdir",
            "$args": [
                "bin",
                "lib",
                "docs",
                "docs/apiguide",
                "test",
                "test/unit_tests"
            ],
            "$options": {

            }
        }
    }
};
```

Then, run the task via [apeman task command][apeman_task_doc_url].

```bash
# Run the task from CLI.
$ apeman task "my-task-01"
```

Option
-------

Values which can be passed to `$options` property.

| Name | Type | Description |
| ---- | ---- | ----------- |


License
-------

This software is released under the [MIT License][my_license_url].


Links
-------

+ [apeman][apeman_url]


[npm_url]: https://www.npmjs.com/
[apeman_url]: https://github.com/apeman-repo/apeman
[apeman_task_doc_url]: https://github.com/apeman-repo/apeman#task
[my_repo_url]: https://github.com/apeman-repo/apeman-task-contrib-mkdir
[my_travis_url]: http://travis-ci.org/apeman-repo/apeman-task-contrib-mkdir
[my_travis_badge_url]: http://img.shields.io/travis/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_license_url]: https://github.com/apeman-repo/apeman-task-contrib-mkdir/blob/master/LICENSE
[my_codeclimate_url]: http://codeclimate.com/github/apeman-repo/apeman-task-contrib-mkdir
[my_codeclimate_badge_url]: http://img.shields.io/codeclimate/github/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_codeclimate_coverage_badge_url]: http://img.shields.io/codeclimate/coverage/github/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_npm_url]: http://www.npmjs.org/package/apeman-task-contrib-mkdir
[my_npm_budge_url]: http://img.shields.io/npm/v/apeman-task-contrib-mkdir.svg?style=flat
[coz_url]: http://okunishinishi.github.io/node-coz/apiguide
